@@ -8,31 +8,33 @@
 #'   partitioning criterion: "es" (Treatment effect sizes) or
 #'   "dm" (Difference in treatment means).
 #' @param maxl maximum number of leaves (\eqn{L}) of the tree. Default value is 10.
-#' @param a1 the minimal sample size of Treatment A (\eqn{T=1}) in a leaf.
-#' @param a2 the minimal sample size of Treatment B (\eqn{T=2}) in a leaf.
+#' @param a1 the minimal sample size of Treatment A (\eqn{T}=1) in a leaf.
+#' If NULL, a1 is set to 1/10 of the sample size of the Treatment A group (assignment is done in the function quint). The minimum value is 2.
+#' @param a2 the minimal sample size of Treatment B (\eqn{T}=2) in a leaf.
+#' If NULL, a2 is set to 1/10 of the sample size of the Treatment B group (assignment is done in the function quint). The minimum value is 2.
 #' @param w a vector with w1 and w2 representing the weights of, respectively,
 #'   the Difference in treatment outcome component and the Cardinality component
 #'   of the partitioning criterion. If crit = "dm", the default value of \eqn{w1}
-#'   is \eqn{1/ log(1+IQR(Y))}. If crit = "es", the default value of \eqn{w1} is
-#'   \eqn{1/log(1+3)}. The default of \eqn{w2} is \eqn{1/log(0.50N)}.
+#'   is 1/ \eqn{log}(1+IQR(Y)). If crit = "es", the default value of \eqn{w1} is
+#'   1/\eqn{log}(1+3). The default of \eqn{w2} is 1/\eqn{log}(0.50\eqn{N}).
 #' @param Bootstrap whether the bias-corrected bootstrap procedure should
 #'   be performed. The default is TRUE.
 #' @param B the number of bootstrap samples to be drawn. The default is 25. We recommend a number of bootstraps of at least 25.
 #' @param dmin the minimum absolute standardized mean difference in
-#'  treatment outcome in each of the two leaves after the first split
-#'  of the tree. This value is used to check whether a qualitative interaction
+#'  treatment outcome in one of the leaves assigned to P1 and one of the leaves
+#'  assigned to P2 of the pruned tree. This value is used to check whether a qualitative interaction
 #'  is present in the data (the qualitative interaction condition); dmin controls
 #'  the balance between Type I error and Type II error. The default value of dmin is 0.30.
 #'
 #' @return A list containing the options.
-#' @references Dusseldorp E., Doove L. and Van Mechelen I. (2015). Quint: An
-#'   R package for the identification of subgroups of clients who differ in which treatment
-#'   alternative is best for them. \emph{Behavior research methods (ahead-of-print)}, 1-14.
-#'   DOI: 10.3758/s13428-015-0594-z.
+#' @references Dusseldorp, E., Doove, L., & Van Mechelen, I. (2016). Quint:
+#'   An R package for the identification of subgroups of clients who differ in
+#'   which treatment alternative is best for them. \emph{Behavior Research Methods,
+#'   48}(2), 650-663. DOI 10.3758/s13428-015-0594-z
 #'
 #'   Dusseldorp E. and Van Mechelen I. (2014). Qualitative interaction
 #'   trees: a tool to identify qualitative treatment-subgroup interactions.
-#'   \emph{Statistics in Medicine, 33(2)}, 219-237. DOI: 10.1002/sim.5933.
+#'   \emph{Statistics in Medicine, 33}(2), 219-237. DOI: 10.1002/sim.5933.
 #'
 #' @seealso \code{\link{quint}}
 #' @examples data(bcrp)
@@ -57,8 +59,23 @@ quint.control<-function(crit="es", maxl = 10, a1=NULL, a2=NULL,
   if(crit != 'es' & crit!= 'dm'){
     stop("Criterion ", crit, " specified is not effect size (es) or difference in means (dm).")}
   #crit="es" (effect size criterion) or "dm" (difference in means criterion)
+
   if(!is.null(a1)){
-    parvec=round(c(a1,a2))}
-  else{parvec=NULL}
+    parvec<-round(c(a1,a2))
+    if(a1<2){warning("a1 should be grater or equal than 2.")}
+      if(!is.null(a2)){
+        if(a2<2){warning("a2 should be grater or equal than 2.")}
+      }
+  }else{
+    if(!is.null(a2)){
+      parvec<-round(c(a1,a2))
+      if(a2<2){warning("a2 should be grater or equal than 2.")}
+    }else{
+      parvec<-NULL
+    }
+  }
+
+
+
   list(crit = crit, maxl = maxl, parvec = parvec, w = w, Boot = Bootstrap, B = B, dmin = dmin)
 }
